@@ -23,63 +23,63 @@ from .tags import include_tag
 from .tags import render_tag
 from .tags import ifchanged_tag
 
-from .filters._math import abs_
-from .filters._math import at_most
-from .filters._math import at_least
-from .filters._math import ceil
-from .filters._math import divided_by
-from .filters._math import floor
-from .filters._math import minus
-from .filters._math import plus
-from .filters._math import round_
-from .filters._math import times
-from .filters._math import modulo
+from .filters.math import abs_
+from .filters.math import at_most
+from .filters.math import at_least
+from .filters.math import ceil
+from .filters.math import divided_by
+from .filters.math import floor
+from .filters.math import minus
+from .filters.math import plus
+from .filters.math import round_
+from .filters.math import times
+from .filters.math import modulo
 
-from .filters._string import capitalize
-from .filters._string import append
-from .filters._string import downcase
-from .filters._string import escape
-from .filters._string import escape_once
-from .filters._string import lstrip
-from .filters._string import newline_to_br
-from .filters._string import prepend
-from .filters._string import remove
-from .filters._string import remove_first
-from .filters._string import replace
-from .filters._string import replace_first
-from .filters._string import slice_
-from .filters._string import split
-from .filters._string import upcase
-from .filters._string import strip
-from .filters._string import rstrip
-from .filters._string import strip_html
-from .filters._string import strip_newlines
-from .filters._string import truncate
-from .filters._string import truncatewords
-from .filters._string import url_encode
-from .filters._string import url_decode
-from .filters._string import base64_encode
-from .filters._string import base64_decode
-from .filters._string import base64_url_safe_encode
-from .filters._string import base64_url_safe_decode
+from .filters.string import capitalize
+from .filters.string import append
+from .filters.string import downcase
+from .filters.string import escape
+from .filters.string import escape_once
+from .filters.string import lstrip
+from .filters.string import newline_to_br
+from .filters.string import prepend
+from .filters.string import remove
+from .filters.string import remove_first
+from .filters.string import replace
+from .filters.string import replace_first
+from .filters.string import slice_
+from .filters.string import split
+from .filters.string import upcase
+from .filters.string import strip
+from .filters.string import rstrip
+from .filters.string import strip_html
+from .filters.string import strip_newlines
+from .filters.string import truncate
+from .filters.string import truncatewords
+from .filters.string import url_encode
+from .filters.string import url_decode
+from .filters.string import base64_encode
+from .filters.string import base64_decode
+from .filters.string import base64_url_safe_encode
+from .filters.string import base64_url_safe_decode
 
-from .filters._array import join
-from .filters._array import first
-from .filters._array import last
-from .filters._array import concat
-from .filters._array import map_
-from .filters._array import reverse
-from .filters._array import sort
-from .filters._array import sort_natural
-from .filters._array import where
-from .filters._array import uniq
-from .filters._array import compact
+from .filters.array import join
+from .filters.array import first
+from .filters.array import last
+from .filters.array import concat
+from .filters.array import map_
+from .filters.array import reverse
+from .filters.array import sort
+from .filters.array import sort_natural
+from .filters.array import where
+from .filters.array import uniq
+from .filters.array import compact
 
-from .filters._misc import size
-from .filters._misc import default
-from .filters._misc import date
+from .filters.misc import size
+from .filters.misc import default
+from .filters.misc import date
 
-from .filters._extra import safe
+from .filters.extra import safe
 
 
 if TYPE_CHECKING:
