@@ -304,7 +304,7 @@ def parse_identifier(stream: TokenStream) -> expression.Identifier:
 def parse_string_or_identifier(
     stream: TokenStream,
     linenum: Optional[int] = None,
-) -> ast.Expression:
+) -> expression.Expression:
     if stream.current.type == TOKEN_IDENTIFIER:
         expr: expression.Expression = parse_identifier(stream)
     elif stream.current.type == TOKEN_STRING:
@@ -444,7 +444,13 @@ class ExpressionParser:
     parsing behavior. Such as adding a logical `NOT` operator.
     """
 
-    def __init__(self):
+    END_EXPRESSION = (
+        TOKEN_PIPE,
+        TOKEN_COMMA,
+        TOKEN_EOF,
+    )
+
+    def __init__(self) -> None:
         self.precedences = PRECEDENCES.copy()
         self.right_associative = RIGHT_ASSOCIATIVE.copy()
 
@@ -487,7 +493,7 @@ class ExpressionParser:
         """Return the precedence of the current token in the stream."""
         precedence = self.precedences.get(stream.current.type, Precedence.LOWEST)
         if stream.current.type in self.right_associative:
-            precedence -= 1
+            precedence = Precedence(precedence - 1)
         return Precedence(precedence)
 
     def parse_filters(self, stream: TokenStream) -> List[expression.Filter]:
@@ -579,8 +585,7 @@ class ExpressionParser:
         left = prefix(stream)
 
         while (
-            stream.peek.type != TOKEN_EOF
-            and stream.peek.type not in (TOKEN_PIPE, TOKEN_COMMA)
+            stream.peek.type not in self.END_EXPRESSION
             and precedence < self.peek_precedence(stream)
         ):
             infix = self.infix_funcs.get(stream.peek.type)
@@ -617,7 +622,7 @@ class ExpressionParser:
         """
         if stream.current.type == TOKEN_EOF:
             # Empty expression.
-            return expression.Nil()
+            return expression.NIL
         return expression.BooleanExpression(expression=self.parse_expression(stream))
 
     def parse_assignment_expression(
